
PShape currentShape;

int tileCount = 10;
float tileWidth, tileHeight;
float shapeSize = 50;
float newShapeSize = shapeSize;
float shapeAngle = 0;
float maxDist;

color shapeColor = color(200, 100, 150);
int fillMode = 0;


//////////////////////////////


void setup() {
  size(600, 600);    // Screen size
  background(100);   // Background color (in void setup() and void draw() for reducing image distortion)
  smooth();          // Antialising enable (in void setup() and void draw() for reducing image distortion)

  tileWidth = width / (float(tileCount));    // Calculation of each segment (width)
  tileHeight = height / (float(tileCount));  // Calculation of each segment (height)

  maxDist = (sqrt(sq(width) + sq(height)));  // Calculation of diagonal

  currentShape = loadShape("image_1.svg");   // Load shape into currentShape
}


void draw() {
  background(100);   // Background color (in void setup() and void draw() for reducing image distortion)
  smooth();          // Antialising enable (in void setup() and void draw() for reducing image distortion)


  for (int gridY = 0; gridY < tileCount; gridY++) {    // Iteration of each height (gridY) step
    for (int gridX = 0; gridX < tileCount; gridX++) {  // Iteration of each width (gridX) step

      float posX = ((tileWidth * gridX) + (tileWidth / 2));
      float posY = ((tileHeight * gridY) + (tileHeight / 2));


      float angle = (atan2(mouseY - posY, mouseX - posX) + radians(shapeAngle)); // Calculate angle between mouse position and actual position of the shape

        if (fillMode == 0) currentShape.enableStyle(); // If fillMode 0 it shows the original SVG shape (enable original style)
      if (fillMode == 1) {                           // if fillMode 1 it shows the fill() (disable original style)
        currentShape.disableStyle();
        fill(shapeColor);
      }

      if (fillMode == 2) {
        currentShape.disableStyle();
        float a = map(dist(mouseX, mouseY, posX, posY), 0, maxDist, 255, 0); // Calculate the distance between mousePosition and each object and maps it to the length of the diagonal (longest distance) to 0-255
        fill(shapeColor, a);
      }
      if (fillMode == 3) {
        currentShape.disableStyle();
        float a = map(dist(mouseX, mouseY, posX, posY), 0, maxDist, 0, 255); // '' Opposit direction
        fill(shapeColor, a);
      }

      pushMatrix();
      translate(posX, posY);       // Real position
      rotate(angle);               // Rotation see 'float angle' calculation
      shapeMode(CENTER);
      noStroke();
      shape(currentShape, 0, 0, newShapeSize, newShapeSize); // shape(image_X, xPos,yPos,size,size)
      popMatrix();
    }
  }
}


void keyPressed() {

  if (key == '1') currentShape = loadShape("image_1.svg"); // SVG is in the middle of the illustrator arboard
  if (key == '2') currentShape = loadShape("image_2.svg"); // SVG is in the left corner of the illustrator artboard
  if (key == '3') currentShape = loadShape("image_3.svg"); // SVG is on the right side of the illustrator artboard


  if (key == 'c' || key == 'C') fillMode = (fillMode+1) % 4; // FillMode divided by 4. The rest ist the important number (modulo)


  if (key == 'g' || key == 'G') { // Increase the tileCount. Produces more objects
    tileCount = tileCount+5;
    if (tileCount > 20) {
      tileCount = 10;
    }
    tileWidth = width/float(tileCount);
    tileHeight = height/float(tileCount);
  }
}

